package Source::Repository::Mass::Settings::FedoraOrigin;

use strict;
use warnings;

use Source::Repository::Mass;
use Source::Shared::FindLocalMirror;
use Source::Shared::Resource::Verbose;
use Source::Shared::Resource::DistroMap;
use Source::Repository::Mass::Settings::OriginImport;

our $VERSION=0.004;
our $verbose=0;

$DistroMap::default_originrepo='fedora';
$Source::Repository::Mass::origin_reponame='Origin repository (Fedora)';

$Source::Repository::Mass::Settings::OriginImport::import_double_posttrim_release=sub {
    my ($originrelease,$destextrel)=@_;
    # google-rubik-fonts-2.100-6.20200314git2e360a2.fc36
    $originrelease=~s/\.20[23][0-9](?:0[1-9]|1[0-2])[0-3][0-9]git[0-9a-f]+$// unless
	$destextrel=~/\.20[23][0-9](?:0[1-9]|1[0-2])[0-3][0-9]git[0-9a-f]+$/;
    return ($originrelease,$destextrel);
};


my $SRPMS='fedora/linux/development/rawhide/Everything/source/tree/Packages';
my $ROOT=&Source::Shared::FindLocalMirror::find_local_mirror([$SRPMS]);
if ($ROOT) {
    foreach my $choice ([
	'russianfedora/free/fedora/development/rawhide/source/SRPMS',
	'fedora/russianfedora/free/fedora/development/rawhide/source/SRPMS',
			],[
	'russianfedora/nonfree/fedora/development/rawhide/source/SRPMS',
	'fedora/russianfedora/nonfree/fedora/development/rawhide/source/SRPMS',
			],[
	'rpmfusion/free/fedora/development/rawhide/Everything/source/SRPMS',
	'fedora/rpmfusion/free/fedora/development/rawhide/Everything/source/SRPMS',
			],[
	'rpmfusion/nonfree/fedora/development/rawhide/Everything/source/SRPMS',
	'fedora/rpmfusion/nonfree/fedora/development/rawhide/Everything/source/SRPMS',
			],[
	'rpmsphere/source',
			]) {
	my $ADD=&Source::Shared::FindLocalMirror::find_local_mirror($choice);
	$ROOT.=":$ADD" if $ADD;
    }
    $Source::Repository::Mass::ORIGINPATH=$ROOT;
} else {
    my $URL=$ENV{'USE_YANDEX_MIRROR'} ?
	'rsync://mirror.yandex.ru' :
	'rsync://fedora.ipacct.com';
	#'rsync://ftp-stud.hs-esslingen.de';
    my $RFURL=$ENV{'USE_YANDEX_MIRROR'} ?
	'rsync://mirror.yandex.ru/fedora/rpmfusion' :
	'rsync://ftp-stud.hs-esslingen.de/rpmfusion';
    $Source::Repository::Mass::ORIGINPATH="$URL/$SRPMS:$RFURL/free/fedora/development/rawhide/Everything/source/SRPMS:$RFURL/nonfree/fedora/development/rawhide/Everything/source/SRPMS";
}
warn 'Mass::Settings::FedoraOrigin: set ORIGINPATH=', $Source::Repository::Mass::ORIGINPATH, "\n" if $verbose or $Source::Shared::verbose>1;

1;
